/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import de.hillenbrand.jreqtools.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;
import de.hillenbrand.util.*;
import java.io.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;

public class GenericRequester {
	static class MyRenderer extends DefaultListCellRenderer {
		private final Icon icon;
		public MyRenderer() { icon = HIconFactory.getMenuIcon("endturn"); }
		public MyRenderer(Icon i) { icon = i; }
		public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
	     		final Component result = super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
	     		setIcon(icon);
			return result;
	}};
	
	public static void main(String [] args)  {
		// init the UI System
		UIPreferences.init();
		
		final String [] choices = new String [] { "One", "Two", "Three", "Four", "Five" };
		
		// make up some types
		final GenericOkCancelRequester.TypeConfig [] types = {
		
			new GenericOkCancelRequester.Tab("Strings & Text"),
			new GenericOkCancelRequester.TypeConfig("String:"				, GenericOkCancelRequester.TYPE_STRING		, "This is a default string."),
			new GenericOkCancelRequester.TypeConfig("Password:"			, GenericOkCancelRequester.TYPE_PASSWORD	, new char [] { 's', 'e', 'c', 'r', 'e', 't' }),
			new GenericOkCancelRequester.TypeConfig("Text:"					, GenericOkCancelRequester.TYPE_TEXT			, "This is a text.\nIt has multiple lines."),
		
			new GenericOkCancelRequester.Tab("Date & Time"),
			new GenericOkCancelRequester.TypeConfig("Date:", GenericOkCancelRequester.TYPE_DATE, java.util.Calendar.getInstance()),
			new GenericOkCancelRequester.TypeConfig("Date:", GenericOkCancelRequester.TYPE_DATE, new java.util.Date(0)),
			new GenericOkCancelRequester.TypeConfig("Date:", GenericOkCancelRequester.TYPE_DATE, new java.sql.Date(1000l*Integer.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Time:", GenericOkCancelRequester.TYPE_TIME_HHMM, "13:30"),
			new GenericOkCancelRequester.TypeConfig("Time:", GenericOkCancelRequester.TYPE_TIME_HHMMSS, "14:30:23"),
			new GenericOkCancelRequester.TypeConfig("Time:", GenericOkCancelRequester.TYPE_TIME_HHMMSSmmm, "23:14:30:120"),
			new GenericOkCancelRequester.TypeConfig("Time:", GenericOkCancelRequester.TYPE_TIME_HHMM, new java.sql.Time(System.currentTimeMillis())),
			new GenericOkCancelRequester.TypeConfig("Time:", GenericOkCancelRequester.TYPE_TIME_HHMMSS, new java.sql.Time(System.currentTimeMillis())),
			new GenericOkCancelRequester.TypeConfig("Time:", GenericOkCancelRequester.TYPE_TIME_HHMMSSmmm, new java.sql.Time(System.currentTimeMillis())),
		
			new GenericOkCancelRequester.Tab("Files & Directories"),
			new GenericOkCancelRequester.TypeConfig("Text File:"				, GenericOkCancelRequester.TYPE_FILE			, new File("/tmp/1.txt"), ".txt"),
			new GenericOkCancelRequester.TypeConfig("Image File:"			, GenericOkCancelRequester.TYPE_FILE			, "/tmp/1.jpg", new String[] {".jpg",".gif"}),
			new GenericOkCancelRequester.TypeConfig("Directory:"			, GenericOkCancelRequester.TYPE_DIRECTORY	, System.getProperty("user.home")),
		
			new GenericOkCancelRequester.Tab("Numbers"),
			new GenericOkCancelRequester.TypeConfig("Byte:"					, GenericOkCancelRequester.TYPE_BYTE			, new Byte(Byte.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Short:"				, GenericOkCancelRequester.TYPE_SHORT			, new Short(Short.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Integer:"				, GenericOkCancelRequester.TYPE_INTEGER		, new Integer(Integer.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Long:"					, GenericOkCancelRequester.TYPE_LONG			, new Long(Long.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Float:"					, GenericOkCancelRequester.TYPE_FLOAT			, new Float(Float.MAX_VALUE)),
			new GenericOkCancelRequester.TypeConfig("Double:"				, GenericOkCancelRequester.TYPE_DOUBLE		, new Double(Double.MAX_VALUE)),
			
			new GenericOkCancelRequester.Tab("Choices & Lists"),
			new GenericOkCancelRequester.TypeConfig("Choice:", GenericOkCancelRequester.TYPE_CHOICE, choices, 
				0, new MyRenderer(HIconFactory.getMenuIcon("attach"))),
			new GenericOkCancelRequester.TypeConfig("Editable Choice:", GenericOkCancelRequester.TYPE_EDITABLE_CHOICE, choices, 
				1, new MyRenderer(HIconFactory.getMenuIcon("2rightarrow"))),
			new GenericOkCancelRequester.TypeConfig("Single Selection:", GenericOkCancelRequester.TYPE_SINGLE_SELECTION, choices, 
				2, new MyRenderer()),
			new GenericOkCancelRequester.TypeConfig("Multi Selection:", GenericOkCancelRequester.TYPE_MULTI_SELECTION, choices, 
				new Integer [] { new Integer(1), new Integer(3), new Integer(4) }, new MyRenderer(HIconFactory.getMenuIcon("bookmark"))),
			
			new GenericOkCancelRequester.Tab("Editable List"),
			new GenericOkCancelRequester.TypeConfig("Editable List:"		, GenericOkCancelRequester.TYPE_EDITABLE_LIST		, choices),
		};
		
		// create and open the test frame
		try
			{
			while (true)
				{
				final GenericOkCancelRequester req = new GenericOkCancelRequester("Title", "Please enter all data:", types);
				if (req.request( (HFrame) null) == GenericOkCancelRequester.OK) 
					{
					for (int i=0; i<types.length; ++i) System.out.println("Result["+i+"]="+req.getResult(i));
					System.exit(0);
					}
				}
			}
		catch (Error x) { System.err.println(x); x.printStackTrace(); }
	}

}
