/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import de.hillenbrand.jreqtools.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;

/**
* This is a demo application that show the capabilities of the de.hillenbrand.jreqtools classes.
*/

public class JReqToolsDemoFrame extends HFrame {
	// App Prefs
	private static final ApplicationPreferences prefs = new ApplicationPreferences("JavaGPE");
	
	// ColorRequester
	ColorRequester 			colorRequester			= new ColorRequester(Helper.GRS("JReqTools.SelectColor"), Color.red);
	JButton					colorRequesterB			= new JButton(Helper.GRS("JReqTools.Color"));
	// FontRequester
	FontRequester 			fontRequester			= new FontRequester(Helper.GRS("JReqTools.SelectFont"), getFont());
	JButton					fontRequesterB			= new JButton(Helper.GRS("JReqTools.Font"));
	// FileRequester
	FileRequester 			fileRequester				= new FileRequester(Helper.GRS("JReqTools.SelectFile"));
	JButton					fileRequesterB			= new JButton(Helper.GRS("JReqTools.File"));
	// ByteRequester
	ByteRequester 			byteRequester			= new ByteRequester(Helper.GRS("JReqTools.EnterByte"), Byte.MAX_VALUE);
	JButton					byteRequesterB			= new JButton(Helper.GRS("JReqTools.Byte"));
	// ShortRequester
	ShortRequester 			shortRequester			= new ShortRequester(Helper.GRS("JReqTools.EnterShort"), Short.MAX_VALUE);
	JButton					shortRequesterB			= new JButton(Helper.GRS("JReqTools.Short"));
	// IntegerRequester
	IntegerRequester 		integerRequester		= new IntegerRequester(Helper.GRS("JReqTools.EnterInteger"), Integer.MAX_VALUE);
	JButton					integerRequesterB		= new JButton(Helper.GRS("JReqTools.Integer"));
	// LongRequester
	LongRequester 			longRequester			= new LongRequester(Helper.GRS("JReqTools.EnterLong"), Long.MAX_VALUE);
	JButton					longRequesterB			= new JButton(Helper.GRS("JReqTools.Long"));
	// LongRequester
	FloatRequester 			floatRequester			= new FloatRequester(Helper.GRS("JReqTools.EnterFloat"), Float.MAX_VALUE);
	JButton					floatRequesterB			= new JButton(Helper.GRS("JReqTools.Float"));
	// LongRequester
	DoubleRequester 		doubleRequester			= new DoubleRequester(Helper.GRS("JReqTools.EnterDouble"), Double.MAX_VALUE);
	JButton					doubleRequesterB		= new JButton(Helper.GRS("JReqTools.Double"));
	// StringRequester
	StringRequester 			stringRequester			= new StringRequester(Helper.GRS("JReqTools.EnterString"), "");
	JButton					stringRequesterB			= new JButton(Helper.GRS("JReqTools.String"));
	// TextRequester
	TextRequester 			textRequester			= new TextRequester(Helper.GRS("JReqTools.EnterText") , "");
	JButton					textRequesterB			= new JButton(Helper.GRS("JReqTools.Text"));
	// PasswordRequester
	PasswordRequester 		passwordRequester		= new PasswordRequester(Helper.GRS("JReqTools.EnterPassword"));
	JButton					passwordRequesterB	= new JButton(Helper.GRS("JReqTools.Password"));
	// LoginRequester
	LoginRequester 			loginRequester			= new LoginRequester(Helper.GRS("JReqTools.LoginM"), 
															Helper.GRS("JReqTools.Login1"), Helper.GRS("JReqTools.Login2"));
	JButton					loginRequesterB			= new JButton(Helper.GRS("JReqTools.Login"));
	// PasswordRequester
	SelectRequester	 		selectRequester			= new SelectRequester(Helper.GRS("JReqTools.PleaseSelect"), 
																new String [] { Helper.GRS("JReqTools.Item1"), Helper.GRS("JReqTools.Item2"), 
																Helper.GRS("JReqTools.Item3") }, Helper.GRS("JReqTools.Item2"));
	JButton					selectRequesterB		= new JButton(Helper.GRS("JReqTools.Selection"));
	// LookAndFeelRequester
	LookAndFeelRequester	lookandfeelRequester	= new LookAndFeelRequester(Helper.GRS("JReqTools.PleaseSelectLookAndFeel"));
	JButton					lookandfeelRequesterB	= new JButton(Helper.GRS("JReqTools.LookAndFeel"));
	// ProgressTracker
	JButton					progressTrackerB		= new JButton(Helper.GRS("JReqTools.ProgressTracker"));
	// Tips
	TipOfTheDay				tipOfTheDay				= new TipOfTheDay(Helper.GRS("JReqTools.Tip.Title"), 
																new String [] { Helper.GRS("JReqTools.Tip.1"), Helper.GRS("JReqTools.Tip.2"), 
																Helper.GRS("JReqTools.Tip.3"),}, 0, true);
	
	private class Task extends ProgressTask {
		int max = 500;
		int current = 0;
		boolean cancelled = false;
		
		public void cancel()  {
			cancelled = true;
		}

		public int getCurrent()  {
			return current;
		}

		public java.lang.String getCurrentText()  {
			return Helper.GRS("JReqTools.Loading") + " " + current + "/" + max;
		}

		public int getMaximum()  {
			return max;
		}

		public int getMinimum()  {
			return 0;
		}

		public void run()  {
			for (int i=0; i<=max && ! cancelled; ++i)
				{
				current = i;
				for (int j=0; j<2000000; ++j); // Do something here :-)
				}
			
			// If you want the ProgressTracker to fill the JProgressBar 100%, then
			// you'll have to wait a bit more then 1 second (this is the worst case).
			
			try { Thread.sleep(1050); } catch(InterruptedException x) {}
		}

	}

	public JReqToolsDemoFrame()  {
		super ("JReqTools");
		
		// Gadgets einrichten
		lookandfeelRequester.setAfterSelection(this);
		fileRequester.addChoosableFileFilter(new FileFilter.SuffixFileFilter(".class", Helper.GRS("JReqTools.JavaClassFiles")));
		fileRequester.addChoosableFileFilter(new FileFilter.SuffixFileFilter(".txt", Helper.GRS("JReqTools.TextFiles")));
		fileRequester.addChoosableFileFilter(new FileFilter.SuffixFileFilter(".java", Helper.GRS("JReqTools.JavaSourceFiles")));
		byteRequester.setDefaultChoices(new Byte [] { new Byte(Byte.MIN_VALUE), new Byte((byte)100), new Byte(Byte.MAX_VALUE), new Byte((byte)0) });
		stringRequester.setDefaultChoices(new String [] { "Peter Parker", "Bettly Barkley", "Tom Tungsten", "John Doe", "Zack Zewa" });
		
		// You might do this for a multi selection file requester:
		//fileRequester.setMultiSelection(true);
		
		// Listeners
		byteRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (byteRequester.request(JReqToolsDemoFrame.this) != ByteRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" + byteRequester.getByte() + "'"); 
				}
		});
		shortRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (shortRequester.request(JReqToolsDemoFrame.this) != ShortRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" + shortRequester.getShort() + "'"); 
				}
		});
		integerRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (integerRequester.request(JReqToolsDemoFrame.this) != IntegerRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" + integerRequester.getInteger() + "'"); 
				}
		});
		longRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (longRequester.request(JReqToolsDemoFrame.this) != LongRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" + longRequester.getLong() + "'"); 
				}
		});
		floatRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (floatRequester.request(JReqToolsDemoFrame.this) != FloatRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" + floatRequester.getFloat() + "'"); 
				}
		});
		doubleRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (doubleRequester.request(JReqToolsDemoFrame.this) != DoubleRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" + doubleRequester.getDouble() + "'"); 
				}
		});
		stringRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (stringRequester.request(JReqToolsDemoFrame.this) != StringRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" +stringRequester.getString() + "'"); 
				}
		});
		textRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (textRequester.request(JReqToolsDemoFrame.this) != TextRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" +textRequester.getText() + "'"); 
				}
		});
		passwordRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (passwordRequester.request(JReqToolsDemoFrame.this) != PasswordRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered") +" '" +passwordRequester.getPassword() + "'"); 
			}
		});
		loginRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (loginRequester.request(JReqToolsDemoFrame.this) != LoginRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouEntered")+" '"+ loginRequester.getLogin()+"' and '"+loginRequester.getPassword()+"'");
			}
		});
		selectRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (selectRequester.request(JReqToolsDemoFrame.this) != SelectRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouSelected") +" '" + selectRequester.getSelectedValue() + "'"); 
			}
		});
		colorRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (colorRequester.request(JReqToolsDemoFrame.this) != ColorRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouSelected") +" '" + colorRequester.getColor() + "'"); 
			}
		});
		fontRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (fontRequester.request(JReqToolsDemoFrame.this) != FontRequester.CANCEL) 
					System.out.println(Helper.GRS("JReqTools.YouSelected") +" '" + fontRequester.getFont() + "'"); 
			}
		});
		fileRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (fileRequester.request(JReqToolsDemoFrame.this) != FileRequester.CANCEL) 
					{
					System.out.println(Helper.GRS("JReqTools.YouSelected") +" '" + fileRequester.getFile() + "'"); 
					// Or you do this for a multiselection file requester
					// File [] f = fileRequester.getFiles();
					// for (int i=0; i<f.length; ++i) System.out.println(Helper.GRS("JReqTools.YouSelected") +" '" + f[i] + "'"); 
					}
			}
		});
		lookandfeelRequesterB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (lookandfeelRequester.request(JReqToolsDemoFrame.this) == LookAndFeelRequester.CANCEL)  return;
				System.out.println(Helper.GRS("JReqTools.YouSelected") +" '" + lookandfeelRequester.getLookAndFeel() + "'"); 
				SwingUtilities.updateComponentTreeUI(SwingUtilities.getRoot(tipOfTheDay));
				pack();
			}
		});
		progressTrackerB.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ProgressTracker m = new ProgressTracker(Helper.GRS("JReqTools.ProgressTrackerMessage"), new Task());
				m.addCancelButton(true);
				m.start(JReqToolsDemoFrame.this);
			}
		});
		
		// Create Choice Panel
		final JPanel p = new JPanel(new GridLayout(4,0,5,5));
		p.add(byteRequesterB);
		p.add(shortRequesterB);
		p.add(integerRequesterB);
		p.add(longRequesterB);
		p.add(floatRequesterB);
		p.add(doubleRequesterB);
		p.add(passwordRequesterB);
		p.add(loginRequesterB);
		p.add(stringRequesterB);
		p.add(textRequesterB);
		p.add(selectRequesterB);
		p.add(colorRequesterB);
		p.add(fontRequesterB);
		p.add(fileRequesterB);
		p.add(lookandfeelRequesterB);
		p.add(progressTrackerB);
		
		// Create Main Panel
		final JPanel panel = new JPanel();
		panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));
		panel.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		panel.add(p);
		
		// Menu 1
		final JMenuBar menubar = new JMenuBar();
		JMenu menu = new JMenu("JReqTools");
		menubar.add(menu);
		JMenuItem item = new JMenuItem(Helper.GRS("JReqTools.About"));
		item.addActionListener(JReqTools.getAboutAction(this, Helper.GRS("JReqTools.AboutText")));
		item.setAccelerator(KeyStroke.getKeyStroke(Helper.GRS("JReqTools.VK_About")));
		menu.add(item);
		item = new JMenuItem(Helper.GRS("JReqTools.Tip"));
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { tipOfTheDay.setVisible(true); }});
		item.setAccelerator(KeyStroke.getKeyStroke(Helper.GRS("JReqTools.VK_Tip")));
		menu.add(item);
		menu.addSeparator();
		item = new JMenuItem(Helper.GRS("JReqTools.Quit"));
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { quit(); }});
		item.setAccelerator(KeyStroke.getKeyStroke(Helper.GRS("JReqTools.VK_Quit")));
		menu.add(item);
		
		// Menu 2
		menu = menubar.add(new JMenu(Helper.GRS("JReqTools.Misc")));
		item = menu.add(new JMenuItem("JReqTools.showError()"));
		item.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { JReqTools.showError(JReqToolsDemoFrame.this, Helper.GRS("JReqTools.Misc.Error")); }
			});
		item = menu.add(new JMenuItem("JReqTools.showException()"));
		item.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { JReqTools.showException(JReqToolsDemoFrame.this, new IllegalArgumentException()); }
			});
		item = menu.add(new JMenuItem("JReqTools.showMessage()"));
		item.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { JReqTools.showMessage(JReqToolsDemoFrame.this, Helper.GRS("JReqTools.Misc.Message")); }
			});
		item = menu.add(new JMenuItem("JReqTools.showNotYetImplemented()"));
		item.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { JReqTools.showNotYetImplemented(JReqToolsDemoFrame.this); }
			});
		item = menu.add(new JMenuItem("JReqTools.showQuestion()"));
		item.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { JReqTools.showQuestion(JReqToolsDemoFrame.this, Helper.GRS("JReqTools.Misc.Question"));  }
			});
		
		// Add everything
		setContentPane(panel);
		setJMenuBar(menubar);
		setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
		setLocation(100,100);
		pack();
		
		// prefs
		prefs.add("JReqToolsDemoFrame", this);
		prefs.add("JReqToolsDemoFrame.ColorRequester", colorRequester);
		prefs.add("JReqToolsDemoFrame.FontRequester", fontRequester);
		prefs.add("JReqToolsDemoFrame.FileRequester", fileRequester);
	}

	public static void main(String [] args)  {
		// init the UI System
		UIPreferences.init();
		
		// create and open the test frame
		final JReqToolsDemoFrame frame = new JReqToolsDemoFrame();
		frame.setVisible(true);
		frame.addWindowListener(new WindowAdapter() { public void windowClosing(WindowEvent e) { frame.quit(); }});
	}

	public void quit()  {
		if (JReqTools.showQuestion(JReqToolsDemoFrame.this, Helper.GRS("JReqTools.AskQuit")))
			{
			prefs.save();
			System.exit(0);
			}
	}

}
