/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import de.hillenbrand.jreqtools.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.text.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;

public class JReqToolsDemoFrame_FileRequester extends HFrame {
	// App Prefs
	private static final ApplicationPreferences prefs = new ApplicationPreferences("JavaGPE");
	
	// variables
	private final FileRequester fileRequester = new FileRequester();
	
	// components
	private final JButton [] buttons = {
		new JButton("request file or directory (load mode)"),
		new JButton("request file or directory (save mode)"),
		new JButton("request multiple files (load mode)"),
		new JButton("request directories only (load mode)"),
		new JButton("request directories only (save mode)"),
	};
	
	public JReqToolsDemoFrame_FileRequester()  {
		super("JavaGPE: FileRequester Demo");
		
		// create and set panel
		setContentPane(createPanel());
		
		// listeners
		buttons[0].addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				fileRequester.setMultiSelection(false);
				fileRequester.setLoadMode();
				fileRequester.setDirectoriesOnly(false);
				request();
			}
		});
		buttons[1].addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				fileRequester.setMultiSelection(false);
				fileRequester.setSaveMode();
				fileRequester.setDirectoriesOnly(false);
				request();
			}
		});
		buttons[2].addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				fileRequester.setMultiSelection(true);
				fileRequester.setLoadMode();
				fileRequester.setDirectoriesOnly(false);
				request();
			}
		});
		buttons[3].addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				fileRequester.setMultiSelection(false);
				fileRequester.setLoadMode();
				fileRequester.setDirectoriesOnly(true);
				request();
			}
		});
		buttons[4].addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				fileRequester.setMultiSelection(false);
				fileRequester.setSaveMode();
				fileRequester.setDirectoriesOnly(true);
				request();
			}
		});
		
		// set bounds
		setLocation(100,100);
		pack();
		
		// prefs
		prefs.add("JReqToolsDemoFrame_FileRequester", this);
		prefs.add("JReqToolsDemoFrame_FileRequester.FileRequester", fileRequester);
	}

	private JPanel createPanel()  {
		// create panel
		final JPanel panel = new JPanel();
		panel.setBorder(UIPreferences.getFrameBorder());
		panel.setLayout(new GridBagLayout());
		
		// create constraints
		final GridBagConstraints c = UIPreferences.getGridBagConstraints();
		
		// add components
		for (int i=0; i<buttons.length; ++i)
			{
			c.gridx = 0; c.gridy=i; c.gridwidth=1; c.gridheight=1; c.weightx=1; c.weighty=0; c.fill = GridBagConstraints.HORIZONTAL;
			panel.add(buttons[i], c);
			}
		
		// return panel
		return panel;
	}

	public static void main(String [] args)  {
		// init UI preferences
		UIPreferences.init();
		
		// create and open the frame
		final JReqToolsDemoFrame_FileRequester test = new JReqToolsDemoFrame_FileRequester();
		test.addWindowListener(new WindowAdapter() { public void windowClosing(WindowEvent e) { prefs.save(); System.exit(0); }});
		test.setVisible(true);
	}

	private void request()  {
		if (fileRequester.request(this) != FileRequester.OK) return;
		
		if (fileRequester.isMultiSelection())
			{
			final File [] files = fileRequester.getFiles();
			String message = "You have selected:\n\n";
			for (int i=0; i<files.length; ++i) message += files[i] + "\n";
			JReqTools.showMessage(this, message);
			}
		else JReqTools.showMessage(this, "You have selected:\n" + fileRequester.getFile());
		
	}

}
