/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import java.awt.*;
import java.awt.event.*;
import java.text.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import de.hillenbrand.jreqtools.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;

public class JReqToolsOkCancelFrame extends OkCancelFrame {
	// App Prefs
	private static final ApplicationPreferences appPrefs = new ApplicationPreferences("JavaGPE");
	
	// components
	protected final HTextField text = new HTextField();
	public JReqToolsOkCancelFrame()  {
		super("JavaGPE: Demo", "This is a demo of a JReqTools OkCancelFrame");
		
		// properties
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		
		// init components
		text.setForeground(Color.red);
		
		// listeners
		
		// add menus
		setJMenuBar(createJMenuBar());
		
		// set bounds
		setBounds(100,100,640,480);
		
		// add prefs
		appPrefs.add("JReqToolsOkCancelFrame", this);
		appPrefs.add("JReqToolsOkCancelFrame.TextField", text);
	}

	protected void cancel()  {
		System.out.println("Cancel");
		exit(0);
	}

	private JMenuBar createJMenuBar()  {
		// variables
		JMenu menu = null;
		JMenuItem item = null;
		
		// menu bar
		final HMenuBar menubar = new HMenuBar();
		
		// menu: file
		menu = new JMenu("File");
		menubar.add(menu);
		
		// item: file
		item = new JMenuItem("New");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("New"); }});
		item.setIcon(HIconFactory.getMenuIcon("filenew"));
		item.setAccelerator(KeyStroke.getKeyStroke("control N"));
		menu.add(item);
		
		// item: open
		item = new JMenuItem("Open");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Open"); }});
		item.setIcon(HIconFactory.getMenuIcon("fileopen"));
		item.setAccelerator(KeyStroke.getKeyStroke("control O"));
		menu.add(item);
		
		// item: close
		item = new JMenuItem("Close");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Close"); }});
		item.setIcon(HIconFactory.getMenuIcon("fileclose"));
		item.setAccelerator(KeyStroke.getKeyStroke("control W"));
		menu.add(item);
		
		// item: quit
		item = new JMenuItem("Quit");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { exit(0); }});
		item.setIcon(HIconFactory.getMenuIcon("exit"));
		item.setAccelerator(KeyStroke.getKeyStroke("control Q"));
		menu.addSeparator();
		menu.add(item);
		
		// menu: edit
		menu = new JMenu("Edit");
		menubar.add(menu);
		
		// item: cut
		item = new JMenuItem("Cut");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Cut"); }});
		item.setIcon(HIconFactory.getMenuIcon("editcut"));
		item.setAccelerator(KeyStroke.getKeyStroke("control X"));
		menu.add(item);
		
		// item: copy
		item = new JMenuItem("Copy");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Copy"); }});
		item.setIcon(HIconFactory.getMenuIcon("editcopy"));
		item.setAccelerator(KeyStroke.getKeyStroke("control C"));
		menu.add(item);
		
		// item: paste
		item = new JMenuItem("Paste");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Paste"); }});
		item.setIcon(HIconFactory.getMenuIcon("editpaste"));
		item.setAccelerator(KeyStroke.getKeyStroke("control V"));
		menu.add(item);
		
		// menu: help
		menu = new JMenu("Help");
		menubar.setHelpMenu(menu);
		
		// item: help
		item = new JMenuItem("Help");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Help"); }});
		item.setIcon(HIconFactory.getMenuIcon("help"));
		menu.add(item);
		
		// return result
		return menubar;
	}

	public static void exit(int value)  {
		appPrefs.save();
		System.exit(value);
	}

	protected JPanel getUserPanel()  {
		// create panel
		final JPanel panel = new JPanel(new GridBagLayout());
		final GridBagConstraints c = UIPreferences.getGridBagConstraints();
		
		// add components
		c.gridx = 0; c.gridy=0; c.gridwidth=1; c.gridheight=1; c.weightx=0; c.weighty=0; c.fill = GridBagConstraints.HORIZONTAL;
		panel.add(new JLabel("Text:", JLabel.LEFT), c);
		c.gridx = 1; c.gridy=0; c.gridwidth=1; c.gridheight=1; c.weightx=1; c.weighty=0; c.fill = GridBagConstraints.HORIZONTAL;
		panel.add(text, c);
		
		// return panel
		return panel;
	}

	public static void main(String [] args)  {
		// init UI preferences
		UIPreferences.init();
		
		// We only support english texts in this program
		Locale.setDefault(Locale.ENGLISH);
		
		// create requester
		final JReqToolsOkCancelFrame test = new JReqToolsOkCancelFrame();
		test.addWindowListener(new WindowAdapter() { public void windowClosing(WindowEvent e) { exit(0); }});
		test.setVisible(true);
	}

	protected void ok()  {
		System.out.println("Ok");
		exit(0);
	}

}
